@@ -2,7 +2,6 @@ use std::os::unix::fs::MetadataExt;
 use std::os::unix::io::AsRawFd;
 use tokio::fs::File;
 
-
 lock_impl!(File);
 allocate!(File);
 allocate_size!(File);
@@ -21,8 +20,20 @@ mod test {
     async fn lock_replace() {
         let tempdir = tempdir::TempDir::new("fs4").unwrap();
         let path = tempdir.path().join("fs4");
-        let file1 = fs::OpenOptions::new().write(true).create(true).open(&path).await.unwrap();
-        let file2 = fs::OpenOptions::new().write(true).create(true).open(&path).await.unwrap();
+        let file1 = fs::OpenOptions::new()
+            .write(true)
+            .create(true)
+            .truncate(true)
+            .open(&path)
+            .await
+            .unwrap();
+        let file2 = fs::OpenOptions::new()
+            .write(true)
+            .create(true)
+            .truncate(true)
+            .open(&path)
+            .await
+            .unwrap();
 
         // Creating a shared lock will drop an exclusive lock.
         file1.lock_exclusive().unwrap();
@@ -31,8 +42,10 @@ mod test {
 
         // Attempting to replace a shared lock with an exclusive lock will fail
         // with multiple lock holders, and remove the original shared lock.
-        assert_eq!(file2.try_lock_exclusive().unwrap_err().raw_os_error(),
-                   lock_contended_error().raw_os_error());
+        assert_eq!(
+            file2.try_lock_exclusive().unwrap_err().raw_os_error(),
+            lock_contended_error().raw_os_error()
+        );
         file1.lock_shared().unwrap();
     }
-}
\ No newline at end of file
+}
