@@ -58,7 +58,9 @@ use std::io::{Error, Result};
 use std::os::windows::ffi::OsStrExt;
 use std::path::Path;
 use windows_sys::Win32::Foundation::ERROR_LOCK_VIOLATION;
-use windows_sys::Win32::Storage::FileSystem::{GetDiskFreeSpaceW, GetVolumePathNameW};
+use windows_sys::Win32::Storage::FileSystem::{
+    GetDiskFreeSpaceExW, GetDiskFreeSpaceW, GetVolumePathNameW,
+};
 
 pub fn lock_error() -> Error {
     Error::from_raw_os_error(ERROR_LOCK_VIOLATION as i32)
@@ -84,23 +86,33 @@ pub fn statvfs(path: &Path) -> Result<FsStats> {
     let root_path: &mut [u16] = &mut [0; 261];
     volume_path(path, root_path)?;
     unsafe {
+        let mut free_space = 0;
+        let mut total_space = 0;
+        let ret = GetDiskFreeSpaceExW(
+            root_path.as_ptr(),
+            &mut free_space,
+            &mut total_space,
+            std::ptr::null_mut(),
+        );
+        if ret == 0 {
+            return Err(Error::last_os_error());
+        }
+
         let mut sectors_per_cluster = 0;
         let mut bytes_per_sector = 0;
-        let mut number_of_free_clusters = 0;
-        let mut total_number_of_clusters = 0;
+        let mut _number_of_free_clusters = 0;
+        let mut _total_number_of_clusters = 0;
         let ret = GetDiskFreeSpaceW(
             root_path.as_ptr(),
             &mut sectors_per_cluster,
             &mut bytes_per_sector,
-            &mut number_of_free_clusters,
-            &mut total_number_of_clusters,
+            &mut _number_of_free_clusters,
+            &mut _total_number_of_clusters,
         );
         if ret == 0 {
             Err(Error::last_os_error())
         } else {
             let bytes_per_cluster = sectors_per_cluster as u64 * bytes_per_sector as u64;
-            let free_space = bytes_per_cluster * number_of_free_clusters as u64;
-            let total_space = bytes_per_cluster * total_number_of_clusters as u64;
             Ok(FsStats {
                 free_space,
                 available_space: free_space,
